@@ -15,7 +15,7 @@ class BaseRepository(implements(InterfaceBaseRepository)):
             query: Query,
     ) -> list[T]:
         """
-        Выполнение запроса
+        Execute query
         """
         items: T = query.firebase_query.get()
         return [
@@ -28,7 +28,7 @@ class BaseRepository(implements(InterfaceBaseRepository)):
             query: Query,
     ) -> list[dict]:
         """
-        Выполнение запроса без преобразования к объектам
+        Execute query raw
         """
         items: T = query.firebase_query.get()
         return [
@@ -41,7 +41,7 @@ class BaseRepository(implements(InterfaceBaseRepository)):
             item_id: str
     ) -> T:
         """
-        Получение по id
+        Get by id
         """
         return self.model.collection.get(item_id)
 
@@ -53,7 +53,7 @@ class BaseRepository(implements(InterfaceBaseRepository)):
             query: Query = None
     ) -> Query:
         """
-        Получение по полю
+        Get by field
         """
         if query:
             query.where(field, operator, value)
@@ -63,6 +63,6 @@ class BaseRepository(implements(InterfaceBaseRepository)):
 
     def update(self, item: T) -> T:
         """
-        Обновление
+        Update
         """
         return item.update()
